pub unsafe extern "C" fn ktxTexture_GetDataSize(
This: *mut ktxTexture,
) -> ktx_size_tExpand description
Returns the size of all the image data of a ktxTexture object in bytes.
pub unsafe extern "C" fn ktxTexture_GetDataSize(
This: *mut ktxTexture,
) -> ktx_size_tReturns the size of all the image data of a ktxTexture object in bytes.